<?php

declare(strict_types=1);

namespace mirzaev\beejee\models;

use mirzaev\beejee\models\model;

use PDO;

/**
 * Модель регистрации, аутентификации и авторизации
 *
 * @package mirzaev\beejee\models
 * @author Arsen Mirzaev Tatyano-Muradovich <red@hood.su>
 */
final class authModel extends model
{
    /**
     * Аутентификация
     *
     * @param string $login Входной
     * @param string $password Пароль
     *
     * @return array|null
     */
    public function auth(string $login, string $password): ?array
    {
        $user = $this->search($login);

        if (empty($user)) {
            return null;
        }

        if (password_verify($password, $user['password'])) {
            // Если пароли совпадают

            // Инициализация сессии
            session_start();
            $_SESSION['id'] = $user['id'];
            $_SESSION['admin'] = $user['admin'];

            // Инициализация cookies
            setcookie("login", $login, ['expires' => time() + 50000, 'SameSite' => 'Strict']);
            setcookie("password", $password, ['expires' => time() + 50000, 'SameSite' => 'Strict']);

            return $user;
        }
    }

    /**
     * Поиск пользователя по входному псевдониму
     *
     * @param string $login Входной
     *
     * @return array|null
     */
    private function search(string $login): ?array
    {
        // Инициализация
        $request = $this->db->prepare("SELECT * FROM `users` WHERE `login` = :login LIMIT 1");

        // Параметры
        $params = [
            ':login' => $login,
        ];

        // Отправка
        $request->execute($params);

        return (array) $request->fetch(PDO::FETCH_ASSOC);
    }
}
